#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 template-haskell-compat-v0208
version:              0.1.6
visibility:           public
id:                   template-haskell-compat-v0208-0.1.6-ESJ7TwOpZxE48gYdg6MRKr
key:                  template-haskell-compat-v0208-0.1.6-ESJ7TwOpZxE48gYdg6MRKr
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:
    https://github.com/nikita-volkov/template-haskell-compat-v0208

synopsis:
    A backwards compatibility layer for Template Haskell newer than 2.8

category:             TemplateHaskell, Compatibility
abi:                  437d0802155dba8f008fc56643a54305
exposed:              True
exposed-modules:      TemplateHaskell.Compat.V0208
hidden-modules:       TemplateHaskell.Compat.V0208.Prelude
import-dirs:
    /usr/lib/ghc-8.10.5/site-local/template-haskell-compat-v0208-0.1.6

library-dirs:
    /usr/lib/ghc-8.10.5/site-local/template-haskell-compat-v0208-0.1.6

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/i386-linux-ghc-8.10.5/template-haskell-compat-v0208-0.1.6

hs-libraries:
    HStemplate-haskell-compat-v0208-0.1.6-ESJ7TwOpZxE48gYdg6MRKr

depends:              base-4.14.2.0 template-haskell-2.16.0.0
haddock-interfaces:
    /usr/share/doc/haskell-template-haskell-compat-v0208/html/template-haskell-compat-v0208.haddock

haddock-html:         /usr/share/doc/haskell-template-haskell-compat-v0208/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

